/*
*	Filename:		Mesh.h
*	Author:			Lars Vidar Magnusson
*	Copyright (C)	LaViMa Development 2006
*/

#ifndef __MESH__
#define __MESH__

#include <vector>
#include <string>

struct tUV {
	float u;
	float v;
};

typedef std::vector<tUV> tUVs;

struct tInfluence {
	int jointIndex;
	MString jointName;
	int vertexIndex;
	float weight;
};	

typedef std::vector<tInfluence> tInfluences;

struct tMesh {
	std::string name;
	std::vector<MPoint> vertices;
	std::vector<MFloatVector> normals;
	tUVs uvs;
	tInfluences influences;
	std::vector<int> shaderIndices;
	std::vector<unsigned int> vertexIndices;
	std::vector<unsigned int> uvIndices;
	std::vector<unsigned int> normalIndices;
};

struct tColor {
	float r, g, b, a;
};

struct tMaterial {
	tColor ambient;

	tColor diffuse;
	MString diffuseMap;

	tColor emmisive;

	tColor specular;
	float shininess;
};

struct tShader {
	std::vector<tMaterial *> materials;
};

#endif	// __MESH__