/*
*	Filename:		RiTETranslator.cpp
*	Author:			Lars Vidar Magnusson
*	Copyright (C)	LaViMa Development 2005
*/

#include <RiTETranslator.h>



MString cRiTETranslator::mVersion = "0.01";

void *cRiTETranslator::creator() {
	return new cRiTETranslator();
}

MStatus cRiTETranslator::reader(const MFileObject &file, const MString& optionsString, MPxFileTranslator::FileAccessMode mode) {
	return MStatus::kSuccess;
}

MStatus cRiTETranslator::writer(const MFileObject &fileObject, const MString &options, MPxFileTranslator::FileAccessMode mode) {
	
	// RiTE Ascii Mesh File
	cTextFileWriter meshFile;
	meshFile.setFileName(fileObject.fullName());

	// RiTE Ascii Animation file
	MString animationFilename = fileObject.path();
	animationFilename += fileObject.name();
	int ext = animationFilename.rindex('.');
	animationFilename = animationFilename.substring(0, ext);
	animationFilename += "raa";
	cTextFileWriter animationFile;
	animationFile.setFileName(animationFilename);

	// RiTE Ascii Shader file
	MString shaderFilename = fileObject.path();
	shaderFilename += fileObject.name();
	ext = shaderFilename.rindex('.');
	shaderFilename = shaderFilename.substring(0, ext);
	shaderFilename += "ras";
	cTextFileWriter shaderFile;
	shaderFile.setFileName(shaderFilename);
	
	MStatus ret;

	ret = mMeshExport.extractMeshes();
	ret = mSkeletonExport.extractSkeleton();
	ret = mAnimationExport.extractAnimation();

	mSkeletonExport.writeSkeleton(meshFile);
	mMeshExport.writeMeshes(meshFile);
	mMeshExport.writeMaterials(shaderFile);
	mAnimationExport.writeAnimation(animationFile);

	meshFile.writeFile();
	animationFile.writeFile();
	shaderFile.writeFile();

	mMeshExport.cleanUp();
	mSkeletonExport.cleanUp();
	mAnimationExport.cleanUp();

	return ret;
}

inline bool cRiTETranslator::haveReadMethod() const {
	return false;
}

inline bool cRiTETranslator::haveWriteMethod() const {
	return true;
}

inline MString cRiTETranslator::defaultExtension() const {
	return "ram";
}

inline bool cRiTETranslator::canBeOpened () const {
	return false;
}

MPxFileTranslator::MFileKind cRiTETranslator::identifyFile(const MFileObject &file,	const char *buffer, short size) const {
	MFileKind ret = kIsMyFileType;
	return ret;
}

bool cRiTETranslator::haveNamespaceSupport() const {
	return false;
}

MString cRiTETranslator::filter() const {
	return MString("");
}