/*
*	Filename:		SkeletonExport.cpp
*	Author:			Lars Vidar Magnusson
*	Copyright (C)	LaViMa Development 2006
*/

#include "SkeletonExport.h"

MStatus cSkeletonExport::extractJoint(MDagPath &jointPath, int parentId) {
	MStatus status = MStatus::kSuccess;

	MFnIkJoint fnJoint(jointPath, &status);
	MFnTransform fnTransform(jointPath, &status);

	tJoint *joint = new tJoint();
	joint->name = jointPath.partialPathName(&status);
	status = fnJoint.getOrientation(joint->orientation);
	status = fnTransform.getRotation(joint->rotation, MSpace::kTransform);
	joint->translation = fnTransform.translation(MSpace::kTransform, &status);
	joint->parent = parentId;
	unsigned int jointIndex = mSkeleton.joints.size();
	mSkeleton.joints.push_back(joint);

	// Child joints
	for(unsigned int childIndex=0; childIndex<jointPath.childCount(); ++childIndex) {
		if(jointPath.child(childIndex, &status).hasFn(MFn::kJoint)) {
			MDagPath childPath;
			childPath.set(jointPath);
			childPath.push(jointPath.child(childIndex, &status));
			status = extractJoint(childPath, jointIndex);
		}
	}
	return status;
}

MStatus cSkeletonExport::extractSkeleton() {
	MStatus status = MStatus::kSuccess;

	// Find skeleton root
	MItDag dagIter(MItDag::kDepthFirst, MFn::kJoint, &status);
	
	MDagPath currentPath; 
	status = dagIter.getPath(currentPath);

	status = extractJoint(currentPath);
		
	return status;
}

void cSkeletonExport::writeSkeleton(cTextFileWriter &writer) {
	writer.addTab();
	writer.add("joints %i\n", mSkeleton.joints.size());
	for(unsigned int i=0; i<mSkeleton.joints.size(); ++i) {
		tJoint *joint = mSkeleton.joints[i];
		writer.addTab();
		writer.add("%i \"%s\"\n", i, joint->name.asChar());
		writer.add("parent %i\n", joint->parent);
		writer.add("orientation %f %f %f %f\n", joint->orientation.x, joint->orientation.y, joint->orientation.z, joint->orientation.w);
		writer.add("translation %f %f %f\n", joint->translation.x, joint->translation.y, joint->translation.z);
    writer.add("rotation %f %f %f %f\n", joint->rotation.x, joint->rotation.y, joint->rotation.z, joint->rotation.w);
		writer.removeTab();
		writer.add("\n");
	}
	writer.removeTab();
	writer.add("\n");
}

void cSkeletonExport::cleanUp() {
	mSkeleton.joints.clear();
}