/*
*	Filename:		FileWriter.cpp
*	Author:			Lars Vidar Magnusson
*	Copyright (C)	LaViMa Development 2005
*/

#include <TextFileWriter.h>

cTextFileWriter::cTextFileWriter() {
	mNumTabs = 0;
}

cTextFileWriter::cTextFileWriter(const MString &fileName) {
	setFileName(fileName);
}

cTextFileWriter::~cTextFileWriter() {
	mBuffer.clear();	// Not needed
}

void cTextFileWriter::add(const char *str, ...) {
	va_list list;
	char tempStr[TEXT_MAX_LENGTH];
	
	va_start(list, str);
	vsprintf(tempStr, str, list);
	va_end(list);

	char newStr[TEXT_MAX_LENGTH];
	
	// Insert tabs if newline is found
	int length = strlen(tempStr);
	int newIndex = 0;
	for(int tempIndex=0; tempIndex<length; tempIndex++) {
		
		newStr[newIndex++] = tempStr[tempIndex];
		
		if(tempStr[tempIndex] == '\n') {
			for(int tab=0; tab<mNumTabs; tab++) {
				newStr[newIndex++] = '\t';
			}
		}
	}
	
	newStr[newIndex] = '\0';
	
	// Append the new string to the existing text in mBuffer
	mBuffer += newStr;
}

void cTextFileWriter::addTab() {
	mNumTabs += 1;
}

void cTextFileWriter::removeTab() {
	if(mNumTabs == 0)
		return;

	mNumTabs -= 1;
}

void cTextFileWriter::writeFile() {
	assert(mFileName.length());

	std::ofstream file;
	file.open(mFileName.asChar(), std::ios::out);
	file.clear();
	file.write(mBuffer.asChar(), mBuffer.length());
}